WeeWX: Installation using apt-get

# apt repository for WeeWX

## Tell the system to trust weewx.com

    wget -qO - https://weewx.com/keys.html | sudo gpg --dearmor --output /etc/apt/trusted.gpg.d/weewx.gpg

## Configure apt

Run the following command to tell apt where to find the WeeWX Python 3 repository.

    echo "deb [arch=all] https://weewx.com/apt/python3 buster main" | sudo tee /etc/apt/sources.list.d/weewx.list

## Install and/or Upgrade WeeWX

    sudo apt-get update
    sudo apt-get install weewx